FaustEvent class final

--- High-Res Automation Event ---

Inheritance
Implemented types
Available extensions

Constructors

FaustEvent()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
eventType int
0 = Strike, 1 = SetFreq, 2 = SetParam
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instrumentId int
getter/setter pair
paramId int
Context-dependent (e.g. 0 = Mute, 1 = Damping)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleOffset int
getter/setter pair
value double
Exact value (Velocity, Hz, or generic float)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited