FaustEventData class

A sample-accurate event record for passing to the native sequencer bridge.

sampleOffset is the position in samples from the start of playback. instrumentId selects which instrument the event targets. eventType 0=strike/stop, 1=set frequency. value is the primary parameter (pitch, velocity). paramId is an optional extended parameter selector.

Constructors

FaustEventData({required int sampleOffset, required int instrumentId, required int eventType, required double value, int paramId = 0})

Properties

eventType int
final
hashCode int
The hash code for this object.
no setterinherited
instrumentId int
final
paramId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleOffset int
final
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited