FaustMinBindings class
Bindings for src/faust_min.h.
Regenerate bindings with dart run ffigen --config ffigen.yaml.
Constructors
- FaustMinBindings(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
FaustMinBindings.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bansuri_create(
double sampleRate) → Pointer< FaustBansuri> - --- Bansuri ---
-
bansuri_destroy(
Pointer< FaustBansuri> bansuri) → void -
bansuri_note_off(
Pointer< FaustBansuri> bansuri) → void -
bansuri_note_on(
Pointer< FaustBansuri> bansuri, double freq, double velocity) → void -
bansuri_render(
Pointer< FaustBansuri> bansuri, int numFrames, Pointer<Float> buffer) → void -
bansuri_set_frequency(
Pointer< FaustBansuri> bansuri, double freq) → void -
bansuri_set_vibrato(
Pointer< FaustBansuri> bansuri, double rate, double depth) → void -
bansuri_strike(
Pointer< FaustBansuri> bansuri, double velocity) → void -
bayan_create(
double sampleRate) → Pointer< FaustBayan> - --- Tabla Bayan ---
-
bayan_destroy(
Pointer< FaustBayan> bayan) → void -
bayan_note_off(
Pointer< FaustBayan> bayan) → void -
bayan_note_on(
Pointer< FaustBayan> bayan, double freq, double velocity) → void -
bayan_render(
Pointer< FaustBayan> bayan, int numFrames, Pointer<Float> buffer) → void -
bayan_set_frequency(
Pointer< FaustBayan> bayan, double freq) → void -
bayan_set_meend(
Pointer< FaustBayan> bayan, double multiplier) → void -
bayan_set_mute(
Pointer< FaustBayan> bayan, int muted) → void -
bayan_strike(
Pointer< FaustBayan> bayan, double velocity) → void -
bell_create(
double sampleRate) → Pointer< FaustBell> - --- Bell ---
-
bell_destroy(
Pointer< FaustBell> bell) → void -
bell_note_off(
Pointer< FaustBell> bell) → void -
bell_note_on(
Pointer< FaustBell> bell, double freq, double velocity) → void -
bell_render(
Pointer< FaustBell> bell, int numFrames, Pointer<Float> buffer) → void -
bell_set_damping(
Pointer< FaustBell> bell, double damping) → void -
bell_set_frequency(
Pointer< FaustBell> bell, double freq) → void -
bell_set_ring_time(
Pointer< FaustBell> bell, double seconds) → void -
bell_strike(
Pointer< FaustBell> bell, double velocity) → void -
bowl_create(
double sampleRate) → Pointer< FaustBowl> - --- Singing Bowl ---
-
bowl_destroy(
Pointer< FaustBowl> bowl) → void -
bowl_note_off(
Pointer< FaustBowl> bowl) → void -
bowl_note_on(
Pointer< FaustBowl> bowl, double freq, double velocity) → void -
bowl_render(
Pointer< FaustBowl> bowl, int numFrames, Pointer<Float> buffer) → void -
bowl_set_duration(
Pointer< FaustBowl> bowl, double seconds) → void -
bowl_set_frequency(
Pointer< FaustBowl> bowl, double freq) → void -
bowl_set_rub(
Pointer< FaustBowl> bowl, double rub) → void -
bowl_set_waver(
Pointer< FaustBowl> bowl, double waver) → void -
bowl_strike(
Pointer< FaustBowl> bowl, double velocity) → void -
cowbell_create(
double sampleRate) → Pointer< FaustCowbell> - --- Cowbell ---
-
cowbell_destroy(
Pointer< FaustCowbell> cowbell) → void -
cowbell_render(
Pointer< FaustCowbell> cowbell, int numFrames, Pointer<Float> buffer) → void -
cowbell_strike(
Pointer< FaustCowbell> cowbell, double velocity) → void -
dayan_create(
double sampleRate) → Pointer< FaustDayan> - --- Tabla Dayan ---
-
dayan_destroy(
Pointer< FaustDayan> dayan) → void -
dayan_note_off(
Pointer< FaustDayan> dayan) → void -
dayan_note_on(
Pointer< FaustDayan> dayan, double freq, double velocity) → void -
dayan_render(
Pointer< FaustDayan> dayan, int numFrames, Pointer<Float> buffer) → void -
dayan_set_frequency(
Pointer< FaustDayan> dayan, double freq) → void -
dayan_set_mute(
Pointer< FaustDayan> dayan, int muted) → void -
dayan_strike(
Pointer< FaustDayan> dayan, double velocity) → void -
flute_create(
double sampleRate) → Pointer< FaustFlute> - --- Flute ---
-
flute_destroy(
Pointer< FaustFlute> flute) → void -
flute_note_off(
Pointer< FaustFlute> flute) → void -
flute_note_on(
Pointer< FaustFlute> flute, double freq, double velocity) → void -
flute_render(
Pointer< FaustFlute> flute, int numFrames, Pointer<Float> buffer) → void -
flute_set_duration(
Pointer< FaustFlute> flute, double seconds) → void -
flute_set_frequency(
Pointer< FaustFlute> flute, double freq) → void -
flute_set_pressure(
Pointer< FaustFlute> flute, double pressure) → void -
flute_set_vibrato(
Pointer< FaustFlute> flute, double rate, double depth) → void -
hihat_create(
double sampleRate) → Pointer< FaustHiHat> -
hihat_destroy(
Pointer< FaustHiHat> hihat) → void -
hihat_render(
Pointer< FaustHiHat> hihat, int numFrames, Pointer<Float> buffer) → void -
hihat_set_openness(
Pointer< FaustHiHat> hihat, double openness) → void -
hihat_strike(
Pointer< FaustHiHat> hihat, double velocity) → void -
instrument_create(
int instrumentID, int execType, double sampleRate) → Pointer< FaustInstrument> -
instrument_destroy(
Pointer< FaustInstrument> inst) → void -
instrument_note_off(
Pointer< FaustInstrument> inst) → void -
instrument_note_on(
Pointer< FaustInstrument> inst, double freq, double velocity, double strike) → void -
instrument_render(
Pointer< FaustInstrument> inst, Pointer<Float> buffer, int numFrames) → void -
instrument_set_parameter(
Pointer< FaustInstrument> inst, Pointer<Char> name, double value) → void -
kick_create(
double sampleRate) → Pointer< FaustKick> -
kick_destroy(
Pointer< FaustKick> kick) → void -
kick_render(
Pointer< FaustKick> kick, int numFrames, Pointer<Float> buffer) → void -
kick_strike(
Pointer< FaustKick> kick, double velocity) → void -
mix_raw_signals(
Pointer< Pointer< inputBuffers, Pointer<Float> >Float> amplitudeScales, Pointer<Int> fadeInSamples, Pointer<Int> fadeOutSamples, Pointer<Int> curveTypes, Pointer<Int> offsetSamples, Pointer<Float> pans, int numTracks, int numSamples, Pointer<Float> outputBuffer, double masterGain) → void - High-Fidelity Stereo Mixer Algorithm:
-
mixer_clear_all(
Pointer< FaustMixer> mixer) → void -
mixer_get_instance(
) → Pointer< FaustMixer> - --- FaustMixer Singleton Endpoints ---
-
mixer_get_sample_rate(
Pointer< FaustMixer> mixer) → double -
mixer_set_master_gain(
Pointer< FaustMixer> mixer, double gain) → void -
mixer_start(
Pointer< FaustMixer> mixer) → int -
mixer_stop(
Pointer< FaustMixer> mixer) → void -
normalize_signal(
Pointer< Float> signal, int numSamples, double targetPeak) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orchestrator_add_sequence(
Pointer< SequenceOrchestrator> orch, Pointer<Char> name, Pointer<UMLSequence> seq) → int -
orchestrator_create(
) → Pointer< SequenceOrchestrator> - --- Real-time Sequence Orchestrator Object Exposure ---
-
orchestrator_destroy(
Pointer< SequenceOrchestrator> orch) → void -
orchestrator_load_song(
Pointer< SequenceOrchestrator> orch, Pointer<Char> directory) → int -
orchestrator_pause(
Pointer< SequenceOrchestrator> orch) → void -
orchestrator_play(
Pointer< SequenceOrchestrator> orch, Pointer<Char> name) → void -
orchestrator_poll_finished(
Pointer< SequenceOrchestrator> orch) → Pointer<Char> -
orchestrator_resume(
Pointer< SequenceOrchestrator> orch) → void -
orchestrator_set_parameter(
Pointer< SequenceOrchestrator> orch, Pointer<Char> name, Pointer<Char> param, double value) → void -
orchestrator_set_weight(
Pointer< SequenceOrchestrator> orch, Pointer<Char> name, double weight) → void -
orchestrator_stop(
Pointer< SequenceOrchestrator> orch) → void -
orchestrator_unload_song(
Pointer< SequenceOrchestrator> orch, Pointer<Char> directory) → void -
piano_create(
double sampleRate) → Pointer< FaustPiano> - --- Piano ---
-
piano_destroy(
Pointer< FaustPiano> piano) → void -
piano_note_off(
Pointer< FaustPiano> piano) → void -
piano_note_on(
Pointer< FaustPiano> piano, double freq, double velocity) → void -
piano_render(
Pointer< FaustPiano> piano, int numFrames, Pointer<Float> buffer) → void -
piano_set_frequency(
Pointer< FaustPiano> piano, double freq) → void -
piano_set_stiffness(
Pointer< FaustPiano> piano, double stiffness) → void -
piano_set_sustain(
Pointer< FaustPiano> piano, double level) → void -
piano_strike(
Pointer< FaustPiano> piano, double velocity, double hardness) → void -
render_automation_sequence(
Pointer< FaustEvent> events, int numEvents, double sampleRate, int totalSamples, Pointer<Float> outputBuffer) → void -
render_sequenced_audio(
Pointer< Int> offsets, Pointer<Int> instrumentIds, Pointer<Float> velocities, Pointer<Float> params, int numTriggers, double baseFreq, double sampleRate, int totalSamples, Pointer<Float> outputBuffer) → void -
ride_create(
double sampleRate) → Pointer< FaustRide> -
ride_destroy(
Pointer< FaustRide> ride) → void -
ride_render(
Pointer< FaustRide> ride, int numFrames, Pointer<Float> buffer) → void -
ride_strike(
Pointer< FaustRide> ride, double velocity) → void -
sax_create(
double sampleRate) → Pointer< FaustSax> - --- Saxophone ---
-
sax_destroy(
Pointer< FaustSax> sax) → void -
sax_note_off(
Pointer< FaustSax> sax) → void -
sax_note_on(
Pointer< FaustSax> sax, double freq, double velocity) → void -
sax_render(
Pointer< FaustSax> sax, int numFrames, Pointer<Float> buffer) → void -
sax_set_frequency(
Pointer< FaustSax> sax, double freq) → void -
sax_set_vibrato(
Pointer< FaustSax> sax, double rate, double depth) → void -
sax_strike(
Pointer< FaustSax> sax, double velocity) → void -
sequence_create(
Pointer< Char> name, int instID, Pointer<Char> umlDataString) → Pointer<UMLSequence> - --- UMLSequence and FaustInstrument Flat Endpoints ---
-
sequence_destroy(
Pointer< UMLSequence> seq) → void -
sequence_get_basefreq(
Pointer< UMLSequence> seq) → double -
sequence_get_bpm(
Pointer< UMLSequence> seq) → double -
sequence_get_grid(
Pointer< UMLSequence> seq) → int -
sequence_get_instrument(
Pointer< UMLSequence> seq) → Pointer<FaustInstrument> -
sequence_set_basefreq(
Pointer< UMLSequence> seq, double freq) → void -
shakuhachi_create(
double sampleRate) → Pointer< FaustShakuhachi> - --- Shakuhachi ---
-
shakuhachi_destroy(
Pointer< FaustShakuhachi> shakuhachi) → void -
shakuhachi_note_off(
Pointer< FaustShakuhachi> shakuhachi) → void -
shakuhachi_note_on(
Pointer< FaustShakuhachi> shakuhachi, double freq, double velocity) → void -
shakuhachi_render(
Pointer< FaustShakuhachi> shakuhachi, int numFrames, Pointer<Float> buffer) → void -
shakuhachi_set_frequency(
Pointer< FaustShakuhachi> shakuhachi, double freq) → void -
shakuhachi_set_vibrato(
Pointer< FaustShakuhachi> shakuhachi, double rate, double depth) → void -
shakuhachi_strike(
Pointer< FaustShakuhachi> shakuhachi, double velocity) → void -
sitar_create(
double sampleRate) → Pointer< FaustSitar> - --- Sitar ---
-
sitar_destroy(
Pointer< FaustSitar> sitar) → void -
sitar_note_off(
Pointer< FaustSitar> sitar) → void -
sitar_note_on(
Pointer< FaustSitar> sitar, double freq, double velocity) → void -
sitar_pluck(
Pointer< FaustSitar> sitar, double velocity) → void -
sitar_render(
Pointer< FaustSitar> sitar, int numFrames, Pointer<Float> buffer) → void -
sitar_set_frequency(
Pointer< FaustSitar> sitar, double freq) → void -
sitar_set_jivari(
Pointer< FaustSitar> sitar, double amount) → void -
sitar_set_sympathetic_gain(
Pointer< FaustSitar> sitar, double gain) → void -
snare_create(
double sampleRate) → Pointer< FaustSnare> -
snare_destroy(
Pointer< FaustSnare> snare) → void -
snare_render(
Pointer< FaustSnare> snare, int numFrames, Pointer<Float> buffer) → void -
snare_strike(
Pointer< FaustSnare> snare, double velocity) → void -
tanpura_create(
double sampleRate) → Pointer< FaustTanpura> - --- Tanpura ---
-
tanpura_destroy(
Pointer< FaustTanpura> tanpura) → void -
tanpura_note_off(
Pointer< FaustTanpura> tanpura) → void -
tanpura_note_on(
Pointer< FaustTanpura> tanpura, double freq, double velocity) → void -
tanpura_render(
Pointer< FaustTanpura> tanpura, int numFrames, Pointer<Float> buffer) → void -
tanpura_set_jivari(
Pointer< FaustTanpura> tanpura, double amount) → void -
tanpura_set_params(
Pointer< FaustTanpura> tanpura, double f1, double f2, double f3, double f4, double decay, double delay) → void -
tanpura_set_playing(
Pointer< FaustTanpura> tanpura, int playing) → void -
tom_create(
double sampleRate) → Pointer< FaustTom> -
tom_destroy(
Pointer< FaustTom> tom) → void -
tom_render(
Pointer< FaustTom> tom, int numFrames, Pointer<Float> buffer) → void -
tom_set_frequency(
Pointer< FaustTom> tom, double freq) → void -
tom_strike(
Pointer< FaustTom> tom, double velocity) → void -
toString(
) → String -
A string representation of this object.
inherited
-
trumpet_create(
double sampleRate) → Pointer< FaustTrumpet> - --- Trumpet ---
-
trumpet_destroy(
Pointer< FaustTrumpet> trumpet) → void -
trumpet_note_off(
Pointer< FaustTrumpet> trumpet) → void -
trumpet_note_on(
Pointer< FaustTrumpet> trumpet, double freq, double velocity) → void -
trumpet_render(
Pointer< FaustTrumpet> trumpet, int numFrames, Pointer<Float> buffer) → void -
trumpet_set_frequency(
Pointer< FaustTrumpet> trumpet, double freq) → void -
trumpet_set_vibrato(
Pointer< FaustTrumpet> trumpet, double rate, double depth) → void -
trumpet_strike(
Pointer< FaustTrumpet> trumpet, double velocity) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited