UmplParser class
Parses the Universal Music Pattern Language (UMPL) into a FaustSequencer.
UMPL extends basic Shruti notation with per-instrument base frequency and gain overrides, inline mathematical expressions for microtonal ratios, and meend glide articulation. Format:
basefreq: 444.0
bpm: 120
grid: 8
1: 444.0 (gain=0.8)
2: 222.0
1Sa . 1Re . 2Pa . . .
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String input) → FaustSequencer